Learn R Programming

SwathXtend (version 1.0.0)

buildSpectraLibPair: Build a spectra library by integrating a pair of spectrum libraries

Description

Build a spectra library by integrating a pair of spectrum libraries

Usage

buildSpectraLibPair(baseLib, extLib, hydroIndex, method = c("time", "hydro", "hydrosequence"), includeLength = FALSE, labelBase = NA, labelAddon = NA, formatBase = c("peakview", "openswath"), formatExt = c("peakview", "openswath"), outputFormat = c("peakview", "openswath"), outputFile = "extendedLibrary.txt", plot = FALSE, clean = TRUE, merge = TRUE, parseAcc = TRUE, consolidateAccession = TRUE, ...)

Arguments

baseLib
a base library data frame or file
extLib
an external/addon library data frame or file
hydroIndex
a data frame or file containing peptide hydrophobicity index
method
a character string to specify the RT alignment method. One of "time" (default), "hydro" and "hydrosequence" can be selected.
includeLength
a logic value representing if include peptide length as a feature for predicting retention time. Only applicable when method is "hydro".
labelBase
a character string to specify the labels of proteins from the base library
labelAddon
a character string to specify the labels of proteins from the addon library
formatBase
a character string denoting the file format of base library file. One of "peakview" (default) and "opensswath"
formatExt
a character string denoting the file format of addon library file. One of "peakview" (default) and "opensswath"
outputFormat
a character string denoting the file format of the output integrated library. One of "peakview" (default) and "opensswath"
outputFile
A character string to specify the sepctra library created
plot
a logic value, representing if plots during processing will be plotted or not
clean
a logic value, representing if the input libraries will be cleaned before integration. Default value is True.
merge
a logic value, representing if the output will be the merged library (default) or the adjusted add-on library.
parseAcc
a logic value, repesenting if the protein accessions will be parsed for consolidation.
consolidateAccession
a logic value, representing if the protein accessions will be consolidated to the base libary in the integrated library. Default value is True.
...
Additional parameters to pass in.

Value

A data frame of the integrated spectrum library

Examples

Run this code
libfiles <- paste(system.file("files",package="SwathXtend"),
c("Lib2.txt","Lib3.txt"),sep="/")
Lib2_3 <- buildSpectraLibPair(libfiles[1], libfiles[2],  
outputFormat="peakview", clean=TRUE, nomod=TRUE, nomc=TRUE)

Run the code above in your browser using DataLab