Learn R Programming

SwathXtend (version 1.0.0)

canonicalFormat: Standardise a sprectrum library data frame

Description

Standardise a sprectrum library data frame

Usage

canonicalFormat(dat, format = c("peakview", "openswath"))

Arguments

dat
a data frame of a spectrum library
format
a character string, representing the format of the input spectrum library. One of "peakview" (default) and "openswath"

Value

a data frame of the library in canonical format

Examples

Run this code
file <- paste(system.file("files",package="SwathXtend"),"Lib1.txt",sep="/")
dat <- read.delim2(file,sep="\t",stringsAsFactor = FALSE, header=TRUE)
dat <- try(canonicalFormat(dat, format = "peakview"))

Run the code above in your browser using DataLab