Learn R Programming

SwathXtend (version 1.0.0)

mlr: Function to implement mlr normalization

Description

Calculate normalization factor, histogram peak and width at half peak for a vector

Usage

mlr(ratio, doplot)

Arguments

ratio
Vector, typically of log ratios
doplot
A logic value, wheter to plot the ratio histograms (FALSE as default)

Value

nf
Normalization factor
peak
Histogram peak
wdt
Width at half peak

Details

References

Find mlr reference.

See Also

Examples

Run this code
mlr(rnorm(1000))
# with shift
mlr(0.5 + rnorm(10000))

Run the code above in your browser using DataLab