Learn R Programming

SwathXtend (version 1.0.0)

mlrGroup: Function to do mlr normalization for a matrix group

Description

Do mlr normalization separately for each set of replicates first, then normalize the resulting matrix

Usage

mlrGroup(mat, Group)

Arguments

mat
Data matrix with replicates as columns
Group
Factor of length ncol(mat)

Value

Resulting normalized matrix of the same size as the initial one

Details

References

*Find reference to mlr paper*

See Also

mlrrep, mlr

Examples

Run this code

res = mlrGroup(iris[,-5], Group=as.factor(c("Sepal", "Sepal", "Petal", "Petal")))

layout(matrix(1:3, nrow=1))
boxplot(log(iris[,-5]), main="Log only")
boxplot(log(medianNorm(iris[,-5])), main="Median")
boxplot(log(res[[1]]), main="MLR")


Run the code above in your browser using DataLab