Learn R Programming

SwathXtend (version 1.0.0)

mlrrep: Function to do mlr normalizatiopn on a matrix of replicates

Description

Calculate all pairwise ratios, log-transform them, find the least variable replicate.

Usage

mlrrep(mat)

Arguments

mat
Data matrix with replicates as columns

Value

mat.norm
Normalized data matrix; matrix assumed positive
wdmat
Square matrix of half peak widths for each ratio of replicates of size ncol(mat)
nfmat
Square matrix of normalization factors for each ratio of replicates of size ncol(mat)
idx
Index of replicate to be used as denominator yielding smallest widths

Details

References

See Also

mlr, mlrGroup

Examples

Run this code
# Example using the iris data
mlrrep(iris[,-5])

# random data
mat = exp(matrix(rnorm(1000),ncol=4))
res = mlrrep(mat) 
layout(matrix(1:2, nrow=1))
boxplot(log(res$mat.norm))
boxplot(log(mat))

Run the code above in your browser using DataLab